#ifndef _TPL_EXTENSIONS_H
#define _TPL_EXTENSIONS_H

#include <telepathy-glib/telepathy-glib.h>

#include "_gen/enums.h"
#include "_gen/cli-misc.h"
#include "_gen/svc-misc.h"

G_BEGIN_DECLS

#include "_gen/gtypes.h"
#include "_gen/interfaces.h"

G_END_DECLS

void tpl_cli_init (void);

#endif /* _TPL_EXTENSIONS_H */

